@@ -10,29 +10,33 @@ import argparse
 import atexit
 import json
 import logging
+import os
+import shutil
 import signal
 import sys
-from os import path, environ
+import tempfile
 from gettext import gettext
+from os import path, environ
 from typing import (
     Union,
     Tuple,
     List
 )
 
+from prance import ValidationError
+from prance.util.url import ResolutionError
+
 from mockintosh.constants import PROGRAM
 from mockintosh.definition import Definition
-from mockintosh.replicas import Request, Response  # noqa: F401
 from mockintosh.helpers import _nostderr, _import_from
+from mockintosh.replicas import Request, Response  # noqa: F401
 from mockintosh.servers import HttpServer, TornadoImpl
 from mockintosh.templating import RenderingQueue, RenderingJob
 from mockintosh.transpilers import OASToConfigTranspiler
 
-from prance import ValidationError
-from prance.util.url import ResolutionError
-
-__version__ = "0.12"
 __location__ = path.abspath(path.dirname(__file__))
+with open(os.path.join(__location__, "res", "version.txt")) as fp:
+    __version__ = fp.read().strip()
 
 should_cov = environ.get('COVERAGE_PROCESS_START', False)
 cov_no_run = environ.get('COVERAGE_NO_RUN', False)
@@ -77,14 +81,14 @@ def start_render_queue() -> Tuple[RenderingQueue, RenderingJob]:
 
 
 def run(
-    source: str,
-    is_file: bool = True,
-    debug: bool = False,
-    interceptors: tuple = (),
-    address: str = '',
-    services_list: list = [],
-    tags: list = [],
-    load_override: Union[dict, None] = None
+        source: str,
+        is_file: bool = True,
+        debug: bool = False,
+        interceptors: tuple = (),
+        address: str = '',
+        services_list: list = [],
+        tags: list = [],
+        load_override: Union[dict, None] = None
 ):
     queue, _ = start_render_queue()
 
@@ -169,7 +173,7 @@ def _handle_oas_input(source: str, convert_args: List[str], direct: bool = False
     return oas_transpiler.transpile(direct=direct)
 
 
-def initiate():
+def initiate(argv=None):
     if should_cov:  # pragma: no cover
         signal.signal(signal.SIGTERM, _gracefully_exit)
         logging.debug('Starting coverage')
@@ -209,16 +213,27 @@ def initiate():
     ap.add_argument(
         '-c',
         '--convert',
-        help='Convert an OpenAPI Specification (Swagger) 2.0 / 3.0 / 3.1 file to %s config. Example: `$ mockintosh petstore.json -c dev.json json`' % PROGRAM.capitalize(),
+        help='Convert an OpenAPI Specification (Swagger) 2.0 / 3.0 / 3.1 file to %s config. '
+             'Example: `$ mockintosh petstore.json -c dev.json json`' % PROGRAM.capitalize(),
         action='store',
         nargs='+',
         metavar=('filename', 'format')
     )
     ap.add_argument('--enable-tags', help='A comma separated list of tags to enable', action='store')
-    args = vars(ap.parse_args())
+    ap.add_argument('--sample-config', help='Writes sample config file to disk', action='store_true')
+    args = vars(ap.parse_args(argv))
 
     interceptors, address, tags = _handle_cli_args(args)
 
+    logging.debug('Current working dir: %s', os.getcwd())
+
+    if args['sample_config']:
+        fname = os.path.abspath(args['source'][0])
+        shutil.copy(os.path.join(__location__, "res", "sample.yml"), fname)
+        logging.info("Created sample configuration file in %r", fname)
+        logging.info("To run it, use the following command:\n    mockintosh %s", os.path.basename(fname))
+        return 0
+
     debug_mode = environ.get('DEBUG', False) or environ.get('MOCKINTOSH_DEBUG', False)
     if debug_mode:
         logging.debug('Tornado Web Server\'s debug mode is enabled!')
@@ -228,6 +243,7 @@ def initiate():
     convert_args = args['convert']
 
     load_override = None
+    logging.debug("Source absolute path: %s", os.path.abspath(source))
 
     if convert_args:
         if len(convert_args) < 2:
@@ -264,3 +280,11 @@ def initiate():
                 tags=tags,
                 load_override=load_override
             )
+
+
+def demo_run():
+    # for Windows, we have this command
+    # to generate demo config and run it right away
+    fname = tempfile.mktemp(prefix="mock-config-", suffix=".yaml")
+    initiate(["--sample-config", fname])
+    initiate([fname])
